==> telectron-1.2.23-py3-none-any.whl: telectron/raw/types/msgs_all_info.py <==
#  telectron - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of telectron.
#
#  telectron is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  telectron is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with telectron.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from telectron.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from telectron.raw.core import TLObject
from telectron import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class MsgsAllInfo(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~telectron.raw.base.MsgsAllInfo`.

    Details:
        - Layer: ``129``
        - ID: ``0x8cc0d131``

    Parameters:
        msg_ids: List of ``int`` ``64-bit``
        info: ``str``
    """

    __slots__: List[str] = ["msg_ids", "info"]

    ID = 0x8cc0d131
    QUALNAME = "types.MsgsAllInfo"

    def __init__(self, *, msg_ids: List[int], info: str) -> None:
        self.msg_ids = msg_ids  # Vector<long>
        self.info = info  # string

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "MsgsAllInfo":
        # No flags
        
        msg_ids = TLObject.read(data, Long)
        
        info = String.read(data)
        
        return MsgsAllInfo(msg_ids=msg_ids, info=info)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        # No flags
        
        data.write(Vector(self.msg_ids, Long))
        
        data.write(String(self.info))
        
        return data.getvalue()

==> telectron-1.2.42-py3-none-any.whl: telectron/raw/types/msgs_all_info.py <==
#  telectron - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of telectron.
#
#  telectron is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  telectron is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with telectron.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from telectron.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from telectron.raw.core import TLObject
from telectron import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class MsgsAllInfo(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~telectron.raw.base.MsgsAllInfo`.

    Details:
        - Layer: ``134``
        - ID: ``0x8cc0d131``

    Parameters:
        msg_ids: List of ``int`` ``64-bit``
        info: ``str``
    """

    __slots__: List[str] = ["msg_ids", "info"]

    ID = 0x8cc0d131
    QUALNAME = "types.MsgsAllInfo"

    def __init__(self, *, msg_ids: List[int], info: str) -> None:
        self.msg_ids = msg_ids  # Vector<long>
        self.info = info  # string

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "MsgsAllInfo":
        # No flags
        
        msg_ids = TLObject.read(b, Long)
        
        info = String.read(b)
        
        return MsgsAllInfo(msg_ids=msg_ids, info=info)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Vector(self.msg_ids, Long))
        
        b.write(String(self.info))
        
        return b.getvalue()
